==> openshift-model-monitoring-5.9.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusRuleExcludeConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PrometheusRuleExcludeConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigBuilder>{
  public PrometheusRuleExcludeConfigBuilder() {
    this(false);
  }
  public PrometheusRuleExcludeConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new PrometheusRuleExcludeConfig(), validationEnabled);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PrometheusRuleExcludeConfig(), validationEnabled);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig instance) {
    this(fluent, instance, false);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRuleName(instance.getRuleName()); 
    fluent.withRuleNamespace(instance.getRuleNamespace()); 
    this.validationEnabled = validationEnabled; 
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig instance) {
    this(instance,false);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRuleName(instance.getRuleName()); 
    this.withRuleNamespace(instance.getRuleNamespace()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig build() {
    PrometheusRuleExcludeConfig buildable = new PrometheusRuleExcludeConfig(fluent.getRuleName(),fluent.getRuleNamespace());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrometheusRuleExcludeConfigBuilder that = (PrometheusRuleExcludeConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/PrometheusRuleExcludeConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PrometheusRuleExcludeConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigBuilder>{
  public PrometheusRuleExcludeConfigBuilder() {
    this(false);
  }
  public PrometheusRuleExcludeConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new PrometheusRuleExcludeConfig(), validationEnabled);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PrometheusRuleExcludeConfig(), validationEnabled);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig instance) {
    this(fluent, instance, false);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRuleName(instance.getRuleName()); 
    fluent.withRuleNamespace(instance.getRuleNamespace()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig instance) {
    this(instance,false);
  }
  public PrometheusRuleExcludeConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRuleName(instance.getRuleName()); 
    this.withRuleNamespace(instance.getRuleNamespace()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.PrometheusRuleExcludeConfig build() {
    PrometheusRuleExcludeConfig buildable = new PrometheusRuleExcludeConfig(fluent.getRuleName(),fluent.getRuleNamespace());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PrometheusRuleExcludeConfigBuilder that = (PrometheusRuleExcludeConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
